@@ -8,6 +8,7 @@ TABLES = {
     'pluto_19v1': {'pluto_19v1': 800_000},
     'pluto_19v2': {'pluto_19v2': 800_000},
     'pluto_20v8': {'pluto_20v8': 800_000},
+    'pluto_21v3': {'pluto_21v3': 800_000},
     'dobjobs': {'dobjobs': 1_000_000},
     'dob_violations': {'dob_violations': 2_000_000},
     'ecb_violations': {'ecb_violations': 1_300_000},
@@ -21,6 +22,10 @@ TABLES = {
         'hpd_registrations_grouped_by_bbl_with_contacts': 130_000
     },
     'dof_sales': {'dof_sales': 60_000},
+    'dof_exemptions': {
+        'dof_exemptions': 740_000,
+        'dof_exemption_classification_codes': 175
+    },
     'rentstab': {'rentstab': 45_000},
     'rentstab_v2': {'rentstab_v2': 40_000},
     'rentstab_summary': {'rentstab_summary': 45_000},
@@ -52,8 +57,12 @@ TABLES = {
         'marshal_evictions_19': 16_000,
         'marshal_evictions_all': 55_000,
     },
+    'nycha_bbls': {
+        'nycha_bbls_18': 5_500,
+    },
     'oath_hearings': {'oath_hearings': 10_000_000},
     'hpd_vacateorders': {'hpd_vacateorders': 4_000},
+    'hpd_litigations': {'hpd_litigations': 170_000},
     'j51_exemptions': {'j51_exemptions': 4_000_000},
     'oca': {
         'oca_index': 1_300_000,
